@@ -2,8 +2,10 @@
 #define TYPES_H
 
 #include <sys/types.h>
+#include <stdbool.h>
 #include <stdlib.h>
 #include <string.h>
+#include <stdbool.h>
 
 #undef eprintf
 #define eprintf(x,y...) fprintf(stderr,x,##y)
@@ -16,6 +18,14 @@
 #endif
 #endif
 
+#ifndef SDB_IPI
+#if defined(__GNUC__) && __GNUC__ >= 4
+// __attribute__((visibility("hidden")))
+#endif
+#define SDB_IPI static
+#endif
+
+
 #if MINGW || __MINGW32__ || __MINGW64__
 #define __MINGW__ 1
 #endif
@@ -32,14 +42,18 @@
 
 #include <inttypes.h>
 #if __CYGWIN__
-#define USE_MMAN 1
+#define HAVE_MMAN 1
 #define ULLFMT "ll"
 #elif __SDB_WINDOWS__
-#define USE_MMAN 0
+#define HAVE_MMAN 0
 #define ULLFMT "I64"
 #else
 #define ULLFMT "ll"
-#define USE_MMAN 1
+#define HAVE_MMAN 1
+#endif
+
+#ifndef USE_MMAN
+#define USE_MMAN HAVE_MMAN
 #endif
 
 #include <unistd.h>
@@ -61,8 +75,16 @@
 #define st64 long long
 #define boolt int
 // TODO: deprecate R_NEW
+#ifndef R_NEW
+//it means we are within sdb
 #define R_NEW(x) (x*)malloc(sizeof(x))
-#define R_NEW0(x) (x*)calloc(1,sizeof(x))
+#endif
+#ifndef R_NEW0
+#define R_NEW0(x) (x*)calloc(1, sizeof(x))
+#endif
+#ifndef R_FREE
+#define R_FREE(x) { free (x); x = NULL; }
+#endif
 #define UT32_MAX ((ut32)0xffffffff)
 #define UT64_MAX ((ut64)(0xffffffffffffffffLL))
 #endif
@@ -79,7 +101,7 @@
 #include "config.h"
 
 static inline int seek_set(int fd, off_t pos) {
-	return ((fd==-1) || (lseek (fd, (off_t) pos, SEEK_SET) == -1))? 0:1;
+	return ((fd == -1) || (lseek (fd, (off_t) pos, SEEK_SET) == -1))? 0:1;
 }
 
 static inline void ut32_pack(char s[4], ut32 u) {
